==> owncloud-8.2.2p3.tgz: owncloud/lib/l10n/lv.js <==
OC.L10N.register(
    "lib",
    {
    "Help" : "Palīdzība",
    "Personal" : "Personīgi",
    "Users" : "Lietotāji",
    "Admin" : "Administratori",
    "Recommended" : "Rekomendēts",
    "Unknown filetype" : "Nezināms datnes tips",
    "Invalid image" : "Nederīgs attēls",
    "today" : "šodien",
    "yesterday" : "vakar",
    "last month" : "pagājušajā mēnesī",
    "last year" : "gājušajā gadā",
    "seconds ago" : "sekundes atpakaļ",
    "web services under your control" : "tīmekļa servisi tavā varā",
    "Application is not enabled" : "Lietotne nav aktivēta",
    "Authentication error" : "Autentifikācijas kļūda",
    "Token expired. Please reload page." : "Pilnvarai ir beidzies termiņš. Lūdzu, pārlādējiet lapu.",
    "%s enter the database username." : "%s ievadiet datubāzes lietotājvārdu.",
    "%s enter the database name." : "%s ievadiet datubāzes nosaukumu.",
    "%s you may not use dots in the database name" : "%s datubāžu nosaukumos nedrīkst izmantot punktus",
    "Oracle connection could not be established" : "Nevar izveidot savienojumu ar Oracle",
    "Oracle username and/or password not valid" : "Nav derīga Oracle parole un/vai lietotājvārds",
    "DB Error: \"%s\"" : "DB kļūda — “%s”",
    "Offending command was: \"%s\"" : "Vainīgā komanda bija “%s”",
    "You need to enter either an existing account or the administrator." : "Jums jāievada vai nu esošs vai administratora konts.",
    "Offending command was: \"%s\", name: %s, password: %s" : "Vainīgā komanda bija \"%s\", vārds: %s, parole: %s",
    "PostgreSQL username and/or password not valid" : "Nav derīga PostgreSQL parole un/vai lietotājvārds",
    "Set an admin username." : "Iestatiet administratora lietotājvārdu.",
    "Set an admin password." : "Iestatiet administratora paroli.",
    "%s shared »%s« with you" : "%s kopīgots »%s« ar jums",
    "Could not find category \"%s\"" : "Nevarēja atrast kategoriju “%s”",
    "Apps" : "Lietotnes",
    "A valid username must be provided" : "Jānorāda derīgs lietotājvārds",
    "A valid password must be provided" : "Jānorāda derīga parole",
    "The username is already being used" : "Šāds lietotājvārds jau tiek izmantots"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");

==> owncloud-10.0.7.tgz: owncloud/lib/l10n/lv.js <==
OC.L10N.register(
    "lib",
    {
    "Unknown filetype" : "Nezināms datnes tips",
    "Invalid image" : "Nederīgs attēls",
    "today" : "šodien",
    "yesterday" : "vakar",
    "last month" : "pagājušajā mēnesī",
    "last year" : "gājušajā gadā",
    "seconds ago" : "sekundes atpakaļ",
    "None" : "Nav",
    "Username" : "Lietotājvārds",
    "Password" : "Parole",
    "Apps" : "Lietotnes",
    "General" : "Vispārīgi",
    "Storage" : "Krātuve",
    "Security" : "Drošība",
    "Encryption" : "Šifrēšana",
    "Sharing" : "Dalīšanās",
    "Search" : "Meklēt",
    "Updates" : "Atjauninājumi",
    "%s enter the database username." : "%s ievadiet datubāzes lietotājvārdu.",
    "%s enter the database name." : "%s ievadiet datubāzes nosaukumu.",
    "%s you may not use dots in the database name" : "%s datubāžu nosaukumos nedrīkst izmantot punktus",
    "Oracle connection could not be established" : "Nevar izveidot savienojumu ar Oracle",
    "Oracle username and/or password not valid" : "Nav derīga Oracle parole un/vai lietotājvārds",
    "DB Error: \"%s\"" : "DB kļūda — “%s”",
    "Offending command was: \"%s\"" : "Vainīgā komanda bija “%s”",
    "You need to enter either an existing account or the administrator." : "Jums jāievada vai nu esošs vai administratora konts.",
    "Offending command was: \"%s\", name: %s, password: %s" : "Vainīgā komanda bija \"%s\", vārds: %s, parole: %s",
    "PostgreSQL username and/or password not valid" : "Nav derīga PostgreSQL parole un/vai lietotājvārds",
    "Set an admin username." : "Iestatiet administratora lietotājvārdu.",
    "Set an admin password." : "Iestatiet administratora paroli.",
    "%s shared »%s« with you" : "%s kopīgots »%s« ar jums",
    "Could not find category \"%s\"" : "Nevarēja atrast kategoriju “%s”",
    "A valid username must be provided" : "Jānorāda derīgs lietotājvārds",
    "A valid password must be provided" : "Jānorāda derīga parole",
    "The username is already being used" : "Šāds lietotājvārds jau tiek izmantots",
    "Help" : "Palīdzība",
    "Settings" : "Iestatījumi",
    "Users" : "Lietotāji",
    "web services under your control" : "tīmekļa servisi tavā varā",
    "Application is not enabled" : "Lietotne nav aktivēta",
    "Authentication error" : "Autentifikācijas kļūda",
    "Token expired. Please reload page." : "Pilnvarai ir beidzies termiņš. Lūdzu, pārlādējiet lapu."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
